.. sectionauthor:: Duncan Macleod <duncan.macleod@ligo.org>

.. _igwn-auth-utils-scitokens:

######################
Working with SciTokens
######################

===
API
===

.. autosummary::
   :toctree: api
   :nosignatures:

   ~igwn_auth_utils.find_scitoken
   ~igwn_auth_utils.scitoken_authorization_header
